# Generated by Django 5.1.3 on 2024-11-24 18:39

import base.base_upload_handlers
import ckeditor.fields
import django.core.validators
import django_countries.fields
import hospital.validators
import uuid
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Hospital",
            fields=[
                (
                    "id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("created_at", models.DateTimeField(auto_now_add=True)),
                ("modified_at", models.DateTimeField(auto_now=True)),
                ("is_deleted", models.BooleanField(default=False)),
                ("deleted_at", models.DateTimeField(blank=True, null=True)),
                ("name", models.CharField(max_length=50, verbose_name="Hospital Name")),
                (
                    "description",
                    ckeditor.fields.RichTextField(
                        blank=True,
                        null=True,
                        verbose_name="Hospital motive and other details",
                    ),
                ),
                (
                    "country",
                    django_countries.fields.CountryField(
                        max_length=2, verbose_name="Country"
                    ),
                ),
                (
                    "logo",
                    models.ImageField(
                        blank=True,
                        null=True,
                        upload_to=base.base_upload_handlers.handle_hospital_logo,
                        validators=[
                            base.base_upload_handlers.handle_image_upload_limit
                        ],
                        verbose_name="Hospital Logo",
                    ),
                ),
                (
                    "bed_capacity",
                    models.IntegerField(
                        validators=[django.core.validators.MinValueValidator(1)],
                        verbose_name="Bed Capacity",
                    ),
                ),
                (
                    "website_url",
                    models.URLField(blank=True, null=True, verbose_name="Website Url"),
                ),
                ("city", models.CharField(max_length=50, verbose_name="City")),
                ("state", models.CharField(max_length=50, verbose_name="State")),
                (
                    "contact_number",
                    models.CharField(
                        max_length=20,
                        validators=[
                            django.core.validators.RegexValidator("^\\+?[0-9\\s\\-]+$")
                        ],
                        verbose_name="Contact Number",
                    ),
                ),
                (
                    "email_address",
                    models.EmailField(max_length=254, verbose_name="Email Address"),
                ),
                (
                    "hospital_type",
                    models.CharField(
                        choices=[
                            ("GENERAL", "General"),
                            ("SPECIALIZED", "Specialized"),
                            ("TEACHING", "Teaching"),
                            ("RESEARCH", "Research"),
                            ("TRAUMACENTER", "Trauma Center"),
                        ],
                        default="GENERAL",
                        max_length=50,
                        verbose_name="Hospital Type",
                    ),
                ),
                (
                    "speciality",
                    ckeditor.fields.RichTextField(
                        blank=True, null=True, verbose_name="Hospital Speciality"
                    ),
                ),
                ("established_date", models.DateField(verbose_name="Establised Date")),
                ("opening_time", models.TimeField(verbose_name="Opening Time")),
                ("closing_time", models.TimeField(verbose_name="Closing Time")),
                (
                    "emergency_contact",
                    models.CharField(
                        max_length=20,
                        validators=[
                            django.core.validators.RegexValidator("^\\+?[0-9\\s\\-]+$")
                        ],
                        verbose_name="Emergency Contact",
                    ),
                ),
                ("ceo", models.CharField(max_length=50, verbose_name="Hospital CEO")),
                (
                    "total_staff",
                    models.IntegerField(
                        validators=[django.core.validators.MinValueValidator(1)],
                        verbose_name="Total Staff",
                    ),
                ),
                (
                    "hospital_rating",
                    models.IntegerField(
                        default=3,
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            hospital.validators.validate_hospital_rating,
                        ],
                        verbose_name="Hospital Rating",
                    ),
                ),
                (
                    "affiliation",
                    models.CharField(
                        blank=True,
                        max_length=50,
                        null=True,
                        verbose_name="Affiliated Hospital/Institution",
                    ),
                ),
                ("facilites", ckeditor.fields.RichTextField(verbose_name="Facilities")),
            ],
            options={
                "verbose_name": "Hospitals",
                "verbose_name_plural": "Hospital",
                "ordering": ("-created_at",),
            },
        ),
    ]
